@@ -109,7 +109,7 @@ sub settings {
         }
         elsif ( $settings->{url_pattern} eq 'query' ) {
             $settings->{url_pattern_reg}
-                = "((\\?.*&)|\\?)wovn=(?<lang>[^&]+)(&|$)";
+                = "((\\?.*&)|\\?)wovn=(?<lang>[^&]+)(&|\$)";
         }
         elsif ( $settings->{url_pattern} eq 'subdomain' ) {
             $settings->{url_pattern_reg} = "^(?<lang>[^.]+)\.";
@@ -139,7 +139,7 @@ sub get_values {
 
     my $values = {};
     if ( $res->is_success ) {
-        $values = eval { JSON::from_json( $res->content ) } || {};
+        $values = eval { JSON::decode_json( $res->content ) } || {};
     }
 
     $values;
